# Disclosure of Use of AI Assistance

*This acknowledgement may be added when AI assistants were used collaborating on WAMP and related projects.*

---

In the preparation of this manuscript and code, the author utilized
AI large language models (LLMs) for assistance:

* **[Claude](https://www.anthropic.com/claude)** by *Anthropic Ireland Limited*
* **[Gemini](https://deepmind.google/models/gemini/)** by *Google Ireland Limited*

under respective terms of service for customers in the European
Economic Area (“EEA”).

The tool functions included brainstorming conceptual frameworks
organizing content structure, and refining language for clarity,
serving the role like an editor or a ghostwriter in the world of
writing and publishing. The author maintained full intellectual
responsibility and creative control over all final ideas, arguments,
and text. The final work remains the product of the authors skill,
judgment, and creative labor.

---
